package es.verdnatura.presentation.view.feature.paletizador.model

class ItemScanVO (
    var expeditionFk:String = "",
    var palletFk:Int,
    var isError:Boolean = false,
    var errorMessage:String = ""
)

class ItemScanList(
    var list:List<ItemScanVO> = listOf()
)

class ItemExpeditionScanVO(
    var id:Int,
    var expeditionFk:Int = 0,
    var Ruta:Int = 0,
    var Ticket:Int= 0,
    var Caja:Int = 0,
    var isError:Boolean = false,
    var errorMessage:String = ""
)

class ItemExpeditionScanList(
    var list:List<ItemExpeditionScanVO> = listOf()
)

